==> groupoffice-com-4.0.47.tar.gz: groupoffice-com-4.0.47/modules/sieve/language/nb.php <==
<?php


$l["name"]= 'Sieve';
$l["scriptname"]= 'Skript';
$l["index"]= 'Indeks';
$l["test"]= 'Test';
$l["not"]= 'Ikke';
$l["type"]= 'Type';
$l["arg"]= 'Argument';
$l["arg1"]= 'Argument1';
$l["arg2"]= 'Argument2';
$l["copy"]= 'Kopier';
$l["target"]= 'Mål';
$l["sieverules"]= 'Regler';
$l["activatedrules"]= 'Aktiverte regler';
$l["field"]= 'Felt';
$l["operator"]= 'Operator';
$l["rules"]= 'Melding';
$l["actions"]= 'Handlinger';
$l["editsieve"]= 'Endre regel';
$l["action"]= 'Handling';
$l["ruletext"]= 'For innkommende eposter';
$l["actiontext"]= '...bruk følgende handlinger';
$l["clear"]= 'Tøm';
$l["active"]= 'Aktiv';
$l["activate"]= 'Aktiver filtersett';
$l["filterset"]= 'Filtersett:';
$l["days"]= 'Gjenta hver x dager';
$l["addresses"]= 'Svar også for disse aliasene';
$l["reason"]= 'Melding';
$l["allfollowingrules"]= 'som oppfyller følgende regler';
$l["somefollowingrules"]= 'som oppfyller en av følgende regler';
$l["allmessages"]= 'alle meldinger';
$l["disablefilter"]= 'Slå av filter';
$l["newsieverule"]= 'Ny regel';
$l["checksieveerror"]= 'Feil ved kontroll av sieve-støtte';
$l["erroremptygrids"]= 'Ett eller begge felter er tomme.';
$l["errorineditmode"]= 'Du holder på å endre et element!\n Du må fullføre den handlingen først.';
$l["subject"]= 'Emne';
$l["from"]= 'Avsender';
$l["to"]= 'Mottaker';
$l["size"]= 'Størrelse';
$l["contains"]= 'inneholder';
$l["notcontains"]= 'inneholder ikke';
$l["is"]= 'er lik';
$l["notis"]= 'er forskjellig fra';
$l["exists"]= 'eksisterer';
$l["notexists"]= 'eksisterer ikke';
$l["fileinto"]= 'Flytt melding til';
$l["copyto"]= 'Kopier melding til';
$l["redirect"]= 'Videresend til';
$l["redirect_to"]= 'Kopier til e-post';
$l["vacation"]= 'Fravær';
$l["reject"]= 'Avvis med melding';
$l["discard"]= 'Forkast';
$l["stop"]= 'Stopp';
$l["under"]= 'Under';
$l["over"]= 'Over';
$l["disabled"]= 'Deaktivert';
$l["subjectcontainsnot"]= 'Emne inneholder ikke';
$l["fromcontainsnot"]= 'Avsender inneholder ikke';
$l["tocontainsnot"]= 'Mottager inneholder ikke';
$l["subjectcontains"]= 'Emne inneholder';
$l["fromcontains"]= 'Avsender inneholder';
$l["tocontains"]= 'Mottager inneholder';
$l["subjectexistsnot"]= 'Emne eksisterer ikke';
$l["fromexistsnot"]= 'Avsender eksisterer ikke';
$l["toexistsnot"]= 'Mottager eksisterer ikke';
$l["subjectexists"]= 'Emne eksisterer';
$l["fromexists"]= 'Avsender eksisterer';
$l["toexists"]= 'Mottaker eksisterer';
$l["markedasspam"]= 'Merket som spam';
$l["sizesmallerthan"]= 'Størrelse mindre enn';
$l["sizebiggerthan"]= 'Størrelse er mer enn';
$l["errorshowtext"]= 'Feil under visning av testlinje';
$l["sendcopyto"]= 'Videresend en kopi til';
$l["forwardto"]= 'Videresend til ';
$l["vacsendevery"]= 'Fravær: Send melding hver';
$l["vacdaystoadresses"]= 'dag(er) for adressen(e)';
$l["vacationmessage"]= 'Melding:';
$l["refusewithmesssage"]= 'Avvis med melding:';
$l["spamflag"]= 'Har spamflagg';
$l["custom"]= 'Egendefinert';
$l["custommailheader"]= 'Mailheader:';
$l["replyToMessage"]='Send svar (eks. fravær)';
$l["subjectequals"]= 'Emne er lik';
$l["subjectequalsnot"]= 'Emne er forskjellig fra';
$l["fromequals"]= 'Fra er lik';
$l["fromequalsnot"]= 'Fra er forskjellig fra';
$l["toequals"]= 'Til er lik';
$l["toequalsnot"]= 'Til er forskjellig fra';
$l['name']='Sieve';
$l['description']='Sette opp sieve e-postfiltere';
$l['active']='aktiv';
$l['standardvacation']='Standard fraværsmelding';
$l['standardvacationmessage']='Jeg er på ferie';

==> groupoffice-com-4.0.97.tar.gz: groupoffice-com-4.0.97/modules/sieve/language/nb.php <==
<?php


$l["name"]= 'Sieve';
$l["scriptname"]= 'Skript';
$l["index"]= 'Indeks';
$l["test"]= 'Test';
$l["not"]= 'Ikke';
$l["type"]= 'Type';
$l["arg"]= 'Argument';
$l["arg1"]= 'Argument1';
$l["arg2"]= 'Argument2';
$l["copy"]= 'Kopier';
$l["target"]= 'Mål';
$l["sieverules"]= 'Regler';
$l["activatedrules"]= 'Aktiverte regler';
$l["field"]= 'Felt';
$l["operator"]= 'Operator';
$l["rules"]= 'Melding';
$l["actions"]= 'Handlinger';
$l["editsieve"]= 'Endre regel';
$l["action"]= 'Handling';
$l["ruletext"]= 'For innkommende eposter';
$l["actiontext"]= '...bruk følgende handlinger';
$l["clear"]= 'Tøm';
$l["active"]= 'Aktiv';
$l["activate"]= 'Aktiver filtersett';
$l["filterset"]= 'Filtersett:';
$l["days"]= 'Gjenta hver x dager';
$l["reason"]= 'Melding';
$l["allfollowingrules"]= 'som oppfyller følgende regler';
$l["somefollowingrules"]= 'som oppfyller en av følgende regler';
$l["allmessages"]= 'alle meldinger';
$l["disablefilter"]= 'Slå av filter';
$l["newsieverule"]= 'Ny regel';
$l["checksieveerror"]= 'Feil ved kontroll av sieve-støtte';
$l["erroremptygrids"]= 'Ett eller begge felter er tomme.';
$l["errorineditmode"]= 'Du holder på å endre et element!\n Du må fullføre den handlingen først.';
$l["subject"]= 'Emne';
$l["from"]= 'Avsender';
$l["to"]= 'Mottaker';
$l["size"]= 'Størrelse';
$l["contains"]= 'inneholder';
$l["notcontains"]= 'inneholder ikke';
$l["is"]= 'er lik';
$l["notis"]= 'er forskjellig fra';
$l["exists"]= 'eksisterer';
$l["notexists"]= 'eksisterer ikke';
$l["fileinto"]= 'Flytt melding til';
$l["copyto"]= 'Kopier melding til';
$l["redirect_to"]= 'Kopier til e-post';
$l["vacation"]= 'Fravær';
$l["reject"]= 'Avvis med melding';
$l["discard"]= 'Forkast';
$l["stop"]= 'Stopp';
$l["under"]= 'Under';
$l["over"]= 'Over';
$l["disabled"]= 'Deaktivert';
$l["subjectcontainsnot"]= 'Emne inneholder ikke';
$l["fromcontainsnot"]= 'Avsender inneholder ikke';
$l["tocontainsnot"]= 'Mottager inneholder ikke';
$l["subjectcontains"]= 'Emne inneholder';
$l["fromcontains"]= 'Avsender inneholder';
$l["tocontains"]= 'Mottager inneholder';
$l["subjectexistsnot"]= 'Emne eksisterer ikke';
$l["fromexistsnot"]= 'Avsender eksisterer ikke';
$l["toexistsnot"]= 'Mottager eksisterer ikke';
$l["subjectexists"]= 'Emne eksisterer';
$l["fromexists"]= 'Avsender eksisterer';
$l["toexists"]= 'Mottaker eksisterer';
$l["markedasspam"]= 'Merket som spam';
$l["sizesmallerthan"]= 'Størrelse mindre enn';
$l["sizebiggerthan"]= 'Størrelse er mer enn';
$l["errorshowtext"]= 'Feil under visning av testlinje';
$l["sendcopyto"]= 'Videresend en kopi til';
$l["forwardto"]= 'Videresend til ';
$l["vacsendevery"]= 'Fravær: Send melding hver';
$l["vacationmessage"]= 'Melding:';
$l["refusewithmesssage"]= 'Avvis med melding:';
$l["spamflag"]= 'Har spamflagg';
$l["custom"]= 'Egendefinert';
$l["custommailheader"]= 'Mailheader:';
$l["replyToMessage"]='Send svar (eks. fraværsmelding)';
$l["subjectequals"]= 'Emne er lik';
$l["subjectequalsnot"]= 'Emne er forskjellig fra';
$l["fromequals"]= 'Fra er lik';
$l["fromequalsnot"]= 'Fra er forskjellig fra';
$l["toequals"]= 'Til er lik';
$l["toequalsnot"]= 'Til er forskjellig fra';
$l['name']='Sieve';
$l['description']='Sette opp sieve e-postfiltere';
$l['active']='Aktiv';
$l['standardvacation']='Standard fraværsmelding';
$l['standardvacationmessage']='Jeg er på ferie';
$l["sendToAddresses"]='Send e-post til disse e-postadressene';
$l["addressesLabel"]= 'Send e-post til disse e-postadressene (adskilt med komma)';
$l["addressesLabelOptional"]= '(Valgfritt) Send kopi til disse e-postadressene (adskilt med komma)';
$l["fileintoLabel"]= 'Flytt e-post til valgte mappe';
$l["copytoLabel"]= 'Kopier e-post til valgte mappe';
$l["toFolder"]= 'Til mappe';
$l["vacsendevery2"]= 'dag(er)';
$l["vacAlsoMailTo"]= 'Send også meldingen til ';
$l['setAction']='Legg til handling';
$l['setFilter']='Legg til kriterium';
$l['sievePort']='Sieve filter portnummer';
$l['useTLS']='Bruk sikker tilkobling for (Sieve) e-postfiltere';
$l['cmdSaveChanges']='Lagre endringer';
$l['pleaseAddCriterium']='Klikk på \'Legg til\' for å legge til et kriterium';
$l['pleaseAddAction']='Klikk på \'Legg til\' for å legge til en handling';
$l['meetingTheseCriteria']='oppfyller følgende kriterier';
$l['pleaseSelectOne']='Vennligst velg';
$l['vacationStart']='Første dag for denne meldingen';
$l['vacationEnd']='Siste dag for denne meldingen';
$l['activateFilter']='Aktiver dette filteret';
$l["redirect_copy_to"]= 'Kopier til e-post';
